@@ -155,6 +155,7 @@ GWeatherParser *
 gweather_parser_new (gboolean use_regions)
 {
     GWeatherParser *parser;
+    int zlib_support;
     int i, keep_going;
     char *filename;
     char *tagname, *format;
@@ -165,6 +166,8 @@ gweather_parser_new (gboolean use_regions)
     parser->use_regions = use_regions;
     parser->locales = g_get_language_names ();
 
+    zlib_support = xmlHasFeature (XML_WITH_ZLIB);
+
     /* First try to load a locale-specific XML. It's much faster. */
     filename = NULL;
     for (i = 0; parser->locales[i] != NULL; i++) {
@@ -177,6 +180,19 @@ gweather_parser_new (gboolean use_regions)
 
 	g_free (filename);
 	filename = NULL;
+
+        if (!zlib_support)
+            continue;
+
+	filename = g_strdup_printf ("%s/Locations.%s.xml.gz",
+				    GWEATHER_XML_LOCATION_DIR,
+				    parser->locales[i]);
+
+	if (g_file_test (filename, G_FILE_TEST_IS_REGULAR))
+	    break;
+
+	g_free (filename);
+	filename = NULL;
     }
 
     /* Fall back on the file containing either all translations, or only
@@ -185,6 +201,11 @@ gweather_parser_new (gboolean use_regions)
     if (!filename)
 	filename = g_strdup (GWEATHER_XML_LOCATION_DIR "/Locations.xml");
 
+    if (!g_file_test (filename, G_FILE_TEST_IS_REGULAR) && zlib_support) {
+        g_free (filename);
+	filename = g_strdup (GWEATHER_XML_LOCATION_DIR "/Locations.xml.gz");
+    }
+
     /* Open the xml file containing the different locations */
     parser->xml = xmlNewTextReaderFilename (filename);
     g_free (filename);
