@@ -34,7 +34,9 @@
 #include "gweather-location.h"
 
 const char *gweather_gettext (const char *str) G_GNUC_FORMAT (1);
+const char *gweather_dpgettext (const char *context, const char *str) G_GNUC_FORMAT (2);
 #define _(str) (gweather_gettext (str))
+#define C_(context, str) (gweather_dpgettext (context, str))
 #define N_(str) (str)
 
 
